Change Log
----------

1.2.6
~~~~~

Released on August 08, 2013

* Added ajax autocomlation for Asset by barcode and/or sn.

* Disabled admin deletetion for Assets.

* Added link to the Pricing App.

* Added field: last modification, asset_id to csv file.

1.0.0
~~~~~

* initial release
